@@ -10,6 +10,7 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("-m", dest="module", required=True)
     parser.add_argument("-w", dest="watch", action="append")
+    parser.add_argument("-x", dest="ignore", action="append")
     parser.add_argument("-v", dest="verbose", action='store_true')
     parser.add_argument("-q", dest="quiet", action='store_true')
 
@@ -25,8 +26,7 @@ def main():
         level = LogLevel.INFO
 
     reloader = start_reloader(
-        "hupper.cli.main",
-        verbose=level,
+        "hupper.cli.main", verbose=level, ignore_files=args.ignore
     )
 
     sys.argv[1:] = unknown_args
@@ -35,7 +35,4 @@ def main():
     if args.watch:
         reloader.watch_files(args.watch)
 
-    return runpy.run_module(
-        args.module,
-        alter_sys=True,
-        run_name="__main__")
+    return runpy.run_module(args.module, alter_sys=True, run_name="__main__")
