@@ -1,25 +1,19 @@
 from __future__ import print_function
 
-from glob import glob
+import fnmatch
 import os
+import re
 import signal
 import sys
 import threading
 import time
+from glob import glob
 
 from .compat import queue
 from .ipc import ProcessGroup
 from .logger import DefaultLogger
-from .utils import (
-    resolve_spec,
-    is_watchdog_supported,
-    is_watchman_supported,
-)
-from .worker import (
-    Worker,
-    is_active,
-    get_reloader,
-)
+from .utils import resolve_spec, is_watchdog_supported, is_watchman_supported
+from .worker import Worker, is_active, get_reloader
 
 
 class FileMonitorProxy(object):
@@ -29,19 +23,24 @@ class FileMonitorProxy(object):
     when it should reload.
 
     """
+
     monitor = None
 
-    def __init__(self, logger):
+    def __init__(self, logger, ignore_files=None):
         self.logger = logger
         self.change_event = threading.Event()
         self.changed_paths = set()
+        self.ignore_files = [
+            re.compile(fnmatch.translate(x)) for x in set(ignore_files or [])
+        ]
 
     def add_path(self, path):
         # if the glob does not match any files then go ahead and pass
         # the pattern to the monitor anyway incase it is just a file that
         # is currently missing
         for p in glob(path) or [path]:
-            self.monitor.add_path(p)
+            if not any(x.match(p) for x in self.ignore_files):
+                self.monitor.add_path(p)
 
     def start(self):
         self.monitor.start()
@@ -76,17 +75,21 @@ class Reloader(object):
     restarting a new worker process.
 
     """
-    def __init__(self,
-                 worker_path,
-                 monitor_factory,
-                 logger,
-                 reload_interval=1,
-                 worker_args=None,
-                 worker_kwargs=None,
-                 ):
+
+    def __init__(
+        self,
+        worker_path,
+        monitor_factory,
+        logger,
+        reload_interval=1,
+        worker_args=None,
+        worker_kwargs=None,
+        ignore_files=None,
+    ):
         self.worker_path = worker_path
         self.worker_args = worker_args
         self.worker_kwargs = worker_kwargs
+        self.ignore_files = ignore_files
         self.monitor_factory = monitor_factory
         self.reload_interval = reload_interval
         self.logger = logger
@@ -134,9 +137,7 @@ class Reloader(object):
 
     def _run_worker(self):
         self.worker = Worker(
-            self.worker_path,
-            args=self.worker_args,
-            kwargs=self.worker_kwargs,
+            self.worker_path, args=self.worker_args, kwargs=self.worker_kwargs
         )
         self.worker.start()
 
@@ -184,15 +185,17 @@ class Reloader(object):
         finally:
             if self.worker.is_alive():
                 self.logger.info(
-                    'Killing server with PID %s.' % self.worker.pid,
+                    'Killing server with PID %s.' % self.worker.pid
                 )
                 self.worker.terminate()
                 self.worker.join()
 
             else:
                 self.worker.join()
-                self.logger.info('Server with PID %s exited with code %d.' %
-                                 (self.worker.pid, self.worker.exitcode))
+                self.logger.info(
+                    'Server with PID %s exited with code %d.'
+                    % (self.worker.pid, self.worker.exitcode)
+                )
 
         self.monitor.clear_changes()
 
@@ -202,15 +205,15 @@ class Reloader(object):
 
     def _wait_for_changes(self):
         self.logger.info('Waiting for changes before reloading.')
-        while (
-            not self.monitor.wait_for_change(self.reload_interval)
+        while not self.monitor.wait_for_change(
+            self.reload_interval
         ):  # pragma: nocover
             pass
 
         self.monitor.clear_changes()
 
     def _start_monitor(self):
-        proxy = FileMonitorProxy(self.logger)
+        proxy = FileMonitorProxy(self.logger, self.ignore_files)
         proxy.monitor = self.monitor_factory(
             proxy.file_changed,
             interval=self.reload_interval,
@@ -270,6 +273,7 @@ def start_reloader(
     monitor_factory=None,
     worker_args=None,
     worker_kwargs=None,
+    ignore_files=None,
 ):
     """
     Start a monitor and then fork a worker process which starts by executing
@@ -303,6 +307,8 @@ def start_reloader(
     python path pointing at an object implementing
     :class:`hupper.interfaces.IFileMonitorFactory`.
 
+    ``ignore_files`` if provided must be an iterable of shell-style patterns
+    to ignore.
     """
     if is_active():
         return get_reloader()
@@ -319,5 +325,6 @@ def start_reloader(
         reload_interval=reload_interval,
         monitor_factory=monitor_factory,
         logger=logger,
+        ignore_files=ignore_files,
     )
     return reloader.run()
